"""
Lynkr SDK - Official Python client library for the Lynkr Service.

This package provides a convenient interface to the Lynkr Service API.
"""

__version__ = "0.1.0"

from .client import LynkrClient

__all__ = ["LynkrClient"]